@@ -855,42 +855,42 @@ and __ocaml_lex_remain_rec lexbuf __ocaml_lex_state =
   | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
       __ocaml_lex_remain_rec lexbuf __ocaml_lex_state
 
-and get_limits r lexbuf =
-   __ocaml_lex_get_limits_rec r lexbuf 89
-and __ocaml_lex_get_limits_rec r lexbuf __ocaml_lex_state =
+and get_limits r some_space lexbuf =
+   __ocaml_lex_get_limits_rec r some_space lexbuf 89
+and __ocaml_lex_get_limits_rec r some_space lexbuf __ocaml_lex_state =
   match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
       | 0 ->
 # 233 "save.mll"
-                (get_limits r lexbuf)
+                (get_limits r true lexbuf)
 # 866 "save.ml"
 
   | 1 ->
 # 234 "save.mll"
-                (get_limits (Some Limits) lexbuf)
+                (get_limits (Some Limits) some_space lexbuf)
 # 871 "save.ml"
 
   | 2 ->
 # 235 "save.mll"
-                (get_limits (Some NoLimits) lexbuf)
+                (get_limits (Some NoLimits) some_space lexbuf)
 # 876 "save.ml"
 
   | 3 ->
 # 236 "save.mll"
-                (get_limits (Some IntLimits) lexbuf)
+                (get_limits (Some IntLimits) some_space lexbuf)
 # 881 "save.ml"
 
   | 4 ->
 # 237 "save.mll"
-                (raise (LimitEof r))
+                (raise (LimitEof (r,some_space)))
 # 886 "save.ml"
 
   | 5 ->
 # 238 "save.mll"
-                (r)
+                (r,some_space)
 # 891 "save.ml"
 
   | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
-      __ocaml_lex_get_limits_rec r lexbuf __ocaml_lex_state
+      __ocaml_lex_get_limits_rec r some_space lexbuf __ocaml_lex_state
 
 and get_sup lexbuf =
    __ocaml_lex_get_sup_rec lexbuf 116
