@@ -324,7 +324,11 @@ http://www.lunatech-research.com/archives/2009/02/03/what-every-web-developer-mu
  let do_encode_fragment putc put c =  match c with
  |  'a'..'z' | 'A'..'Z' | '0'..'9' | '-' | '_' | '~' | '.'
    -> putc c
- | _ -> put (sprintf "%%%02X" (Char.code c))
+ | _ ->
+    let c = match c with
+    | '\n'|'\t' -> ' '
+    | _ -> c in
+    put (sprintf "%%%02X" (Char.code c))
 
  let do_encode putc put specific u =
    let len = String.length u in
@@ -368,4 +372,4 @@ http://www.lunatech-research.com/archives/2009/02/03/what-every-web-developer-mu
 
   let decode_fragment putc _put u = do_decode putc (MyLexing.from_string u)
 
-# 372 "url.ml"
+# 376 "url.ml"
