@@ -1295,7 +1295,7 @@ and
      if (not !input_verb || MyStack.empty stack_lexbuf)
         && env = !Scan.cur_env then begin
       finish () ;
-      scan_this Scan.main ("\\end"^env) ;
+      scan_this Scan.main ("\\csname end"^env^"\\endcsname") ;
       Scan.top_close_block "" ;
       Scan.close_env !Scan.cur_env ;
       ()
@@ -1650,8 +1650,9 @@ let noeof lexer lexbuf =
            ("End of file in environment: ``"^ !Scan.cur_env^"'' ("^s^")"))
   | EndVerb -> ()
 
-let open_verbenv star =
-  Scan.top_open_block "pre" (getclass "verbatim") ;
+let open_verbenv ?(style="") star =
+  let attr = if style = "" then getclass "verbatim" else sprintf {| style="%s" |} style in
+  Scan.top_open_block "pre" attr ;
   let process =
     wrap_eat_fst_nl
       (if star then
@@ -2408,12 +2409,19 @@ let init_listings () =
 register_init "listings" init_listings
 ;;
 
-
 register_init "fancyvrb"
     (fun () ->
       def_code "\\@Verbatim"
         (fun lexbuf ->
-          let p, f = open_verbenv false in
+          let style= get_prim_arg lexbuf in
+          let p, f = open_verbenv ~style false in
+          let p =
+            let nxt = ref false in
+            fun () ->
+              if !nxt then scan_this Scan.main {|\bgroup\verb@start@line|} ;
+              p () ;
+              if !nxt then scan_this Scan.main {|\egroup|} ;
+              nxt := true in
           noeof (scan_byline p f) lexbuf) ;
       def_code "\\@endVerbatim" close_verbenv)
 ;;
@@ -2501,4 +2509,4 @@ def_code "\\@scaninput"
 let rien = ()
 end
 
-# 2505 "verb.ml"
+# 2513 "verb.ml"
